@@ -3,7 +3,9 @@ import builtins
 import traceback
 from textwrap import dedent
 
-from python_runner import PatchedStdinRunner
+import pytest
+
+from python_runner import PatchedStdinRunner, PatchedSleepRunner
 from python_runner.output import OutputBuffer
 
 OutputBuffer.flush_time = 0.1
@@ -454,6 +456,27 @@ def test_await_syntax_error():
     )
 
 
+def test_sleep():
+    class SleepRunner(MyRunner, PatchedSleepRunner):
+        pass
+
+    check_simple(
+        "import time; time.sleep(123)",
+        [
+            (
+                "sleep",
+                {"seconds": 123},
+            ),
+        ],
+        runner=SleepRunner(callback=default_callback),
+    )
+
+
+def test_interrupt():
+    with pytest.raises(KeyboardInterrupt):
+        check_simple("raise KeyboardInterrupt", [])
+
+
 def test_await():
     global events
     events = []
